@@ -118,11 +118,11 @@ class VariableOsInstallLocaleDumpkeys(LocaleVariable):
 
 class VariableOsInstallLocaleLocale(LocaleVariable):
     """
-    Locale (at example: ru_RU.UTF-8)
+    Locale (at example: ru_RU.utf8)
     """
 
     def get(self):
-        """locale (example: ru_RU.UTF-8)"""
+        """locale (example: ru_RU.utf8)"""
         return self.getFieldByLang("locale",
                                    self.Get('os_install_locale_lang'))
 
